#ifndef XDKWRL_SPHERE_H
#define XDKWRL_SPHERE_H

#include <xdkwrl/config.h>
#include <xdkwrl/node.h>
#include <xdkwrl/fieldtypes/sffloat.h>

namespace wrl
{
  //++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  // Interface of Sphere
  //++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  class XDKWRL_API Sphere : public Node
  {
   public:
     Sphere(const char* name="");
     virtual ~Sphere();
     virtual inline unsigned int nbFields() const;
     virtual FieldHandle field(const std::string& n);
     virtual FieldHandle field(unsigned int i);
     virtual bool isSetToDefaultValue(unsigned int i) const;
     virtual inline unsigned int nbEventsIn() const;
     virtual EventInHandle eventIn(const std::string& n);
     virtual EventInHandle eventIn(unsigned int i);
     virtual inline unsigned int nbEventsOut() const;
     virtual EventOutHandle eventOut(const std::string& n);
     virtual EventOutHandle eventOut(unsigned int i);
     inline const char* typeName() const;
     virtual Node* duplicate() const;
     virtual Node* duplicate(std::map<const Node*,Node*>&) const;
     /*!@name Exposed Fields
      * A field that is capable of receiving events via an eventIn to 
      * change its value(s), and generating events via an eventOut 
      * when its value(s) change.
      */
      //!@{
     //!@}
     /*!@name Fields
      * A property or attribute of a node. Each node type has a fixed set
      * of fields. Fields may contain various kinds of data and one or many
      * values. Each field has a default value.
      */
      //!@{
      /*!
       * See <a href="#_details" class="md">Detailed Description</a>
       * for meaning of this field.
       * Default value is set to 
       \code
       radius = 1.0f;
        \endcode
       */
       SFFloat    radius;
     //!@}
     /*!@name Events In
      * 
      */
      //!@{
  //!@}
     /*!@name Events Out
      * 
      */
      //!@{
  //!@}
  };
};
//************************************************************
// Implementation of Sphere
//************************************************************
/*!
 * Returns <code>"Sphere"</code>. Useful for printing.
 */
inline const char*
wrl::Sphere::typeName() const
{
  return "Sphere";
}
/*!
 * Returns the number of fields (exposed or not) for this node type.
 */
inline unsigned int
wrl::Sphere::nbFields() const
{
   return 1;
}
/*!
 * Returns the number of events in for this node type.
 */
inline unsigned int
wrl::Sphere::nbEventsIn() const
{
   return 0;
}
/*!
 * Returns the number of events out for this node type.
 */
inline unsigned int
wrl::Sphere::nbEventsOut() const
{
   return 0;
}
#endif // XDKWRL_SPHERE_H

// Local variables section.
// This is only used by emacs!
// Local Variables:
// ff-search-directories: ("../../" "../../../src/xdkwrl/nodes")
// End:
